---
feature_story: FS_02_25_41_81
feature_title: func_id_query_enum_items
feature_status: TEST
---

Keywords: `describe`, `query`, `enum`

The feature provides a func to enumerate available arg options (based on existing arg values).

This is one of the funcs listed in FS_80_45_89_81 integrated functions.

It does exactly the same thing as `ServerAction.DescribeLineArgs` invoked on `Alt+Shift+Q`,
but when it is invoked as function, it is invoked via `Enter` (`ServerAction.RelayLineArgs`).

Historically, verb "describe" was used for this functionality, but "enum" is closer to its meaning
(effectively, available options are sort of dynamic enum whose item set changes with provided args).

# Available implementations

See available implementations in `DistinctValuesQuery`.
